@@ -2,9 +2,8 @@ from asdf.extension import Converter
 
 
 class EquivalencyConverter(Converter):
-    tags = ["tag:astropy.org:astropy/units/equivalency-*"]
-
-    types = ["astropy.units.equivalencies.Equivalency"]
+    tags = ("tag:astropy.org:astropy/units/equivalency-*",)
+    types = ("astropy.units.equivalencies.Equivalency",)
 
     def to_yaml_tree(self, obj, tag, ctx):
         return [
